/// <reference types="node" resolution-mode="require"/>
import http from 'http';
import Koa from 'koa';
import Router from 'koa-router';
import { JsonClassConverterInput, StringClassConverterInput } from '../class_converter.js';
import { JsonProxy } from './json_proxy.js';
/**
 * JsonRpcServer.
 * Minimal, dev-friendly mechanism to create a server from an object.
 */
export declare class JsonRpcServer {
    private handler;
    private createApi;
    private disallowedMethods;
    private log;
    proxy: JsonProxy;
    constructor(handler: object, stringClassMap: StringClassConverterInput, objectClassMap: JsonClassConverterInput, createApi: boolean, disallowedMethods?: string[], log?: import("../../log/logger.js").DebugLogger);
    /**
     * Get an express app object.
     * @param prefix - Our server prefix.
     * @returns The app object.
     */
    getApp(prefix?: string): Koa<Koa.DefaultState, Koa.DefaultContext>;
    /**
     * Get a router object wrapping our RPC class.
     * @param prefix - The server prefix.
     * @returns The router object.
     */
    private getRouter;
    /**
     * Start this server with koa.
     * @param port - Port number.
     * @param prefix - Prefix string.
     */
    start(port: number, prefix?: string): void;
}
/**
 * Creates a router for handling a plain status request that will return 200 status when running.
 * @param apiPrefix - The prefix to use for all api requests
 * @returns - The router for handling status requests.
 */
export declare function createStatusRouter(apiPrefix?: string): Router<any, {}>;
/**
 * Creates an http server that forwards calls to the underlying instance and starts it on the given port.
 * @param instance - Instance to wrap in a JSON-RPC server.
 * @param jsonRpcFactoryFunc - Function that wraps the instance in a JSON-RPC server.
 * @param port - Port to listen in.
 * @returns A running http server.
 */
export declare function startHttpRpcServer<T>(instance: T, jsonRpcFactoryFunc: (instance: T) => JsonRpcServer, port: string | number): http.Server;
//# sourceMappingURL=json_rpc_server.d.ts.map